@@ -1,5 +1,5 @@
 /*
- *  $Id: insert_tcpo.c,v 1.1.1.1 1998/11/27 06:04:10 route Exp $
+ *  $Id: insert_tcpo.c,v 1.2 1999/01/31 21:05:41 route Exp $
  *
  *  libnet
  *  insert_tcpo.c - Inserts TCP options into a prebuilt IP packet
@@ -50,7 +50,10 @@ insert_tcpo(struct tcpoption *opt, u_char opt_len, u_char *buf)
         /*
          *  Hey retard, where's the TCP header?
          */
-        DEBUG("insert_tcpo: tried to insert TCP options into a NON TCP packet!\n");
+#if (__DEBUG)
+        fprintf(stderr,
+            "insert_tcpo: tried to insert TCP options into a NON TCP packet!\n");
+#endif
         return (-1);
     }
 
@@ -61,7 +64,10 @@ insert_tcpo(struct tcpoption *opt, u_char opt_len, u_char *buf)
         /*
          *  Nope.  Too big.
          */
-        DEBUG("insert_tcpo: options list would result in too large of a packet\n");
+#if (__DEBUG)
+        fprintf(stderr,
+            "insert_tcpo: options list would result in too large of a packet\n");
+#endif
         return (-1);
     }
 
